==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/GetIntegrationRuntimeConnectionInfoPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.GetIntegrationRuntimeConnectionInfoPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property integrationRuntimeName Integration runtime name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetIntegrationRuntimeConnectionInfoPlainArgs(
    public val integrationRuntimeName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.GetIntegrationRuntimeConnectionInfoPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.GetIntegrationRuntimeConnectionInfoPlainArgs =
        com.pulumi.azurenative.synapse.inputs.GetIntegrationRuntimeConnectionInfoPlainArgs.builder()
            .integrationRuntimeName(integrationRuntimeName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetIntegrationRuntimeConnectionInfoPlainArgs].
 */
@PulumiTagMarker
public class GetIntegrationRuntimeConnectionInfoPlainArgsBuilder internal constructor() {
    private var integrationRuntimeName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Integration runtime name
     */
    @JvmName("tpupnocvniehkssp")
    public suspend fun integrationRuntimeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.integrationRuntimeName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("dhqisjywagrdtyyn")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("vyypkrupdsyxuxkv")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetIntegrationRuntimeConnectionInfoPlainArgs =
        GetIntegrationRuntimeConnectionInfoPlainArgs(
            integrationRuntimeName = integrationRuntimeName ?: throw
                PulumiNullFieldException("integrationRuntimeName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/GetIntegrationRuntimeConnectionInfoPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.GetIntegrationRuntimeConnectionInfoPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property integrationRuntimeName Integration runtime name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetIntegrationRuntimeConnectionInfoPlainArgs(
    public val integrationRuntimeName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.GetIntegrationRuntimeConnectionInfoPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.GetIntegrationRuntimeConnectionInfoPlainArgs =
        com.pulumi.azurenative.synapse.inputs.GetIntegrationRuntimeConnectionInfoPlainArgs.builder()
            .integrationRuntimeName(integrationRuntimeName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetIntegrationRuntimeConnectionInfoPlainArgs].
 */
@PulumiTagMarker
public class GetIntegrationRuntimeConnectionInfoPlainArgsBuilder internal constructor() {
    private var integrationRuntimeName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Integration runtime name
     */
    @JvmName("lvyukjohuktstfpx")
    public suspend fun integrationRuntimeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.integrationRuntimeName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("vptgwsaxrqjvmncx")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("guavcgblfitvhsfb")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetIntegrationRuntimeConnectionInfoPlainArgs =
        GetIntegrationRuntimeConnectionInfoPlainArgs(
            integrationRuntimeName = integrationRuntimeName ?: throw
                PulumiNullFieldException("integrationRuntimeName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
        )
}
